<img align="right" width="200" height="200" src="https://raw.githubusercontent.com/openego/eDisGo/dev/doc/images/edisgo_logo.png">


# Overview

[![Coverage Status](https://coveralls.io/repos/github/openego/eDisGo/badge.svg?branch=dev)](https://coveralls.io/github/openego/eDisGo?branch=dev)
[![Tests & coverage](https://github.com/openego/eDisGo/actions/workflows/tests-coverage.yml/badge.svg)](https://github.com/openego/eDisGo/actions/workflows/tests-coverage.yml)


# eDisGo

The python package eDisGo serves as a toolbox to evaluate flexibility measures
as an economic alternative to conventional grid expansion in
medium and low voltage grids.
See [documentation](https://edisgo.readthedocs.io/en/dev/) for further information.


# LICENSE

Copyright (C) 2017 Reiner Lemoine Institut gGmbH

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program. If not, see https://www.gnu.org/licenses/.
